<?php
/*
Plugin Name: Suble Greetz
Plugin URI: https://github.com/SubleXBle/Suble-Greetz/
Description: Ein einfaches Plugin mit einer Admin-Seite zur Begrüßungssteuerung
Version: 1.2.0
Author: SubleXBle
Author URI: https://suble.org/
License: GPL2
*/

// Verhindert direkten Zugriff
if (!defined('ABSPATH')) {
    exit;
}

// Login-Zähler & Shortcode einbinden
include_once plugin_dir_path(__FILE__) . 'login-counter.php';

// Admin-Menü hinzufügen
function suble_greetz_add_admin_menu() {
    add_menu_page(
        'Suble Greetz',
        'Suble Greetz',
        'manage_options',
        'suble-greetz',
        'suble_greetz_admin_page',
        'dashicons-smiley',
        100
    );
}
add_action('admin_menu', 'suble_greetz_add_admin_menu');

// Einstellungen registrieren
function suble_greetz_register_settings() {
    for ($i = 1; $i <= 5; $i++) {
        register_setting('suble_greetz_settings', 'suble_greetz_time_' . $i);
        register_setting('suble_greetz_settings', 'suble_greetz_greeting_' . $i);
    }
    
    // Hinzufügen der Einstellungen für Shortname (Benutzer-Spitzname)
    register_setting('suble_greetz_settings', 'suble_greetz_shortname_display_option');
    register_setting('suble_greetz_settings', 'suble_greetz_shortname_guest_name');
    register_setting('suble_greetz_settings', 'suble_greetz_shortname_profile_link');
}
add_action('admin_init', 'suble_greetz_register_settings');

// Inhalt der Admin-Seite
function suble_greetz_admin_page() {
    ?>
    <div class="wrap">
        <h1>Suble Greetz</h1>
        <h2>immer Zeitgemäße Anreden</h2>
        <p>
           Dieses Addon stellt dir 3 Shortcodes zur Verfügung:
            <li><code>[greetz]</code> um eine Tagesabhängige Begrüßung einzufügen</li>
            <li><code>[shortnamez]</code> um Benutzer oder Rolle des Benutzers anzuzeigen</li>
            <li><code>[timez]</code> um einem Benutzer anzuzeigen, wie oft er sich bereits an der Seite angemeldet hat</li>
        </p>
        <p>Diese Shortcodes kannst du überall auf deinen Seiten und Posts anwenden.</p>
        <h2>Tageszeiten konfigurieren:</h2>
        
        <?php if (isset($_GET['settings-updated'])) : ?>
            <div id="suble-greetz-message" class="updated notice is-dismissible">
                <p>Einstellungen gespeichert!</p>
            </div>
            <script>
                setTimeout(function() {
                    document.getElementById('suble-greetz-message').style.display = 'none';
                }, 2000);
            </script>
        <?php endif; ?>
        
        <form method="post" action="options.php">
            <?php
            settings_fields('suble_greetz_settings');
            do_settings_sections('suble_greetz_settings');
            
            // Zeige die Begrüßungseinstellungen nebeneinander an
            for ($i = 1; $i <= 5; $i++) {
                // echo '<h5>Zeiteinheit ' . $i . '</h3>';
                echo '<div class="greetz-settings-row">';
                echo '<div class="greetz-settings-field"><label>Zeitspanne:</label> <input type="time" name="suble_greetz_time_' . $i . '" value="' . esc_attr(get_option('suble_greetz_time_' . $i)) . '" class="greetz-time-input"></div>';
                echo '<div class="greetz-settings-field"><label>Begrüßung:</label> <input type="text" name="suble_greetz_greeting_' . $i . '" value="' . esc_attr(get_option('suble_greetz_greeting_' . $i)) . '" class="greetz-greeting-input"></div>';
                echo '</div>';
            }
    
            // Optionen für Shortname
            echo '<h2>Anzeigenamen Einstellungen</h2>';
            echo '<label><b>Gästenamen</b> (für nicht angemeldete Benutzer):</label> <input type="text" name="suble_greetz_shortname_guest_name" value="' . esc_attr(get_option('suble_greetz_shortname_guest_name', 'Gast')) . '" class="greetz-guestname-input"><br>';
            echo '<label><b>Shortname-Option</b> (Anzeigename oder Rolle):</label>';
            echo '<select name="suble_greetz_shortname_display_option">';
            echo '<option value="nickname" ' . selected(get_option('suble_greetz_shortname_display_option', 'nickname'), 'nickname', false) . '>Anzeigename</option>';
            echo '<option value="role" ' . selected(get_option('suble_greetz_shortname_display_option', 'nickname'), 'role', false) . '>Benutzerrolle</option>';
            echo '</select><br>';
            echo '<label><b>Benutzerprofil verlinken:</b> </label> <input type="checkbox" name="suble_greetz_shortname_profile_link" value="1" ' . checked(1, get_option('suble_greetz_shortname_profile_link', 0), false) . '><br>';

            submit_button();
            ?>
        </form>
    </div>

    <style>
        /* CSS für das nebeneinander liegende Layout */
        .greetz-settings-row {
            display: flex;
            justify-content: flex-start; /* Stellt sicher, dass die Felder nebeneinander sind */
            gap: 15px; /* Abstand zwischen den Feldern */
            margin-bottom: 15px; /* Abstand nach der Zeile */
        }

        /* Anpassen der Breite für jedes Eingabefeld */
        .greetz-settings-field {
            width: auto; /* Setze die Breite der Felder auf auto */
            min-width: 120px; /* Mindestbreite für jedes Eingabefeld */
        }

        /* Eingabefeld für Zeitspanne - Maximale Breite auf Inhalt beschränken */
        .greetz-time-input {
            width: 80px; /* Passt die Breite auf die typischen HH:MM Format */
        }

        /* Eingabefeld für Begrüßung - Feste Breite */
        .greetz-greeting-input {
            width: 180px; /* Kurzeres Eingabefeld für Begrüßung */
        }

        /* Eingabefeld für Gästenamen - Feste Breite */
        .greetz-guestname-input {
            width: 150px; /* Kurzes Eingabefeld für den Gästenamen */
        }

        /* Stellt sicher, dass alle Eingabefelder gleichmäßig dargestellt werden */
        input[type="text"], input[type="time"], select {
            width: auto !important;
        }
    </style>
    <?php
}
// Ende Admin Seite

// Shortcode für den Shortname
function suble_greetz_shortname_shortcode() {
    $current_user = wp_get_current_user();
    $display_option = get_option('suble_greetz_shortname_display_option', 'nickname');
    $profile_link_enabled = get_option('suble_greetz_shortname_profile_link', false);

    if ($current_user->exists()) {
        $output = ($display_option === 'role') ? implode(", ", $current_user->roles) : esc_html($current_user->nickname);

        if ($profile_link_enabled && $display_option === 'nickname') {
            $profile_url = get_edit_profile_url($current_user->ID);
            return '<a href="' . esc_url($profile_url) . '">' . $output . '</a>';
        }
        return $output;
    }
    $guest_name = get_option('suble_greetz_shortname_guest_name', 'Gast');
    return esc_html($guest_name);
}
add_shortcode('shortnamez', 'suble_greetz_shortname_shortcode');

// Funktion für tageszeitabhängige Begrüßung
function suble_greetz_get_greeting() {
    $current_time = current_time('H:i');
    $greetings = [];

    for ($i = 1; $i <= 5; $i++) {
        $time = get_option('suble_greetz_time_' . $i);
        $greeting = get_option('suble_greetz_greeting_' . $i);
        if ($time && $greeting) {
            $greetings[$time] = $greeting;
        }
    }

    ksort($greetings);
    
    $selected_greeting = 'Hallo!';
    $previous_time = '00:00';
    
    foreach ($greetings as $time => $greeting) {
        if ($current_time >= $previous_time && $current_time < $time) {
            break;
        }
        $selected_greeting = $greeting;
        $previous_time = $time;
    }

    return $selected_greeting;
}

// Shortcode für die Begrüßung mit deaktiviertem Cache
function suble_greetz_shortcode() {
    nocache_headers();
    return suble_greetz_get_greeting();
}
add_shortcode('greetz', 'suble_greetz_shortcode');

// Plugin-Update-Checker
// Sicherstellen, dass der Update-Checker vorhanden ist
require plugin_dir_path(__FILE__) . 'plugin-update-checker/plugin-update-checker.php';

// Initialisierung mit der neuen Klassenstruktur
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

$updateChecker = PucFactory::buildUpdateChecker(
    'https://github.com/SubleXBle/Suble-Greetz/',
    __FILE__,
    'suble-greetz'
);

// richtige Branch setzen:
$updateChecker->setBranch('latest');

// Icon für Plugin einfügen
function suble_greetz_set_plugin_icon($plugin_data, $plugin_file) {
    if ($plugin_file === plugin_basename(__FILE__)) {
        $plugin_data['icons'] = array(
            '2x'  => plugin_dir_url(__FILE__) . 'assets/icon-256x256.png', // Großes Icon
            '1x'  => plugin_dir_url(__FILE__) . 'assets/icon-128x128.png', // Kleines Icon
            //'svg' => plugin_dir_url(__FILE__) . 'assets/icon.svg', // Falls SVG genutzt wird
        );
    }
    return $plugin_data;
}
add_filter('plugin_details_api_result', 'suble_greetz_set_plugin_icon', 10, 2);

